/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.batch.planner.web.internal.display.context;

import com.liferay.batch.engine.BatchEngineTaskContentType;
import com.liferay.frontend.taglib.clay.servlet.taglib.util.SelectOption;
import com.liferay.petra.string.StringPool;

import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import java.util.Map;
import java.util.Set;
import java.util.stream.Collectors;
import java.util.stream.Stream;

/**
 * @author Igor Beslic
 */
public class EditBatchPlannerPlanDisplayContext {

	public EditBatchPlannerPlanDisplayContext(
		Map<String, String> headlessEndpoints) {

		_headlessEndpoints = Collections.unmodifiableMap(headlessEndpoints);
	}

	public List<SelectOption> getExternalTypeSelectOptions() {
		List<SelectOption> selectOptions = new ArrayList<>();

		for (BatchEngineTaskContentType batchEngineTaskContentType :
				BatchEngineTaskContentType.values()) {

			selectOptions.add(
				new SelectOption(
					batchEngineTaskContentType.toString(),
					batchEngineTaskContentType.toString()));
		}

		return selectOptions;
	}

	public Map<String, String> getHeadlessEndpoints() {
		return _headlessEndpoints;
	}

	public List<SelectOption> getSelectOptions() {
		Set<Map.Entry<String, String>> entries = _headlessEndpoints.entrySet();

		Stream<Map.Entry<String, String>> stream = entries.stream();

		List<SelectOption> selectOptions = new ArrayList<>();

		selectOptions.add(new SelectOption(StringPool.BLANK, StringPool.BLANK));

		selectOptions.addAll(
			stream.map(
				entry -> new SelectOption(entry.getKey(), entry.getValue())
			).collect(
				Collectors.toList()
			));

		return selectOptions;
	}

	private final Map<String, String> _headlessEndpoints;

}